============
django-home
============

django-home is a responsive movie website app.Visitors can choose between MOVIES

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "home" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...,
        "django_home",
    ]

2. Include the app URLconf in your project urls.py like this::

    path("home/", include("django_home.urls")),

3. Run ``python manage.py migrate`` to create the models.

4. Start the development server and visit the admin to create a app.

5. Visit the ``/home/`` URL to participate in the poll.
